package paystation.domain;

import org.junit.jupiter.api.*;
import static org.junit.jupiter.api.Assertions.*;

import static org.hamcrest.MatcherAssert.assertThat; 
import static org.hamcrest.Matchers.*;

/** Testcases for the BetaTown pay station with progressive rate policy.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestProgressiveRate {
  RateStrategy rs;

  @BeforeEach public void setUp() {
    rs = new ProgressiveRateStrategy();
  }
  
  /** Test a single hour parking */
  @Test public void shouldDisplay60MinFor150cent() {
    // First hour: $1.5
    assertThat(rs.calculateTime(150), is(60) /* minutes */); 
  }

  /** Test two hours parking */
  @Test public void shouldGive120MinFor350cent() {
    // Two hours: $1.5+2.0
    assertThat(rs.calculateTime(350), is(2*60) /* minutes */); 
  }

  /** Test three hours parking */
  @Test public void shouldGive180MinFor650cent() {
    // Three hours: $1.5+2.0+3.0
    assertThat(rs.calculateTime(650), is(3*60) /* minutes */); 
  }

  /** Test four hours parking */
  @Test public void shouldGive240MinFor950cent() {
    assertThat(rs.calculateTime(950), is(4*60) /* minutes */); 
  }
}
