import java.util.*;

/** Demonstration of using Bloch's Builder pattern for building
 * a person identity object. 
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class DemoBlochBuilder {
  public static void main(String[] args) {
    System.out.println( "======= Demonstration of Bloch's Builder =======");
    
    // Define the identify of the person 'John Hansen'
    PersonIdentity john = 
      new PersonIdentity.PersonBuilder("Hansen").
      addGivenName("John").
      addGivenName("William").
      setGender(Gender.Male).
      setPersonID("171100-1357").
      addPhoneNumber("+45 9812 3456").
      addPhoneNumber("+45 9812 5687").
      setBirthTime(1998, Calendar.NOVEMBER, 17). 
      build();
    
    System.out.println("=== John: ===");
    System.out.println(john.toString());

    // Define the identify of the person 'Ann Nielsen'
    PersonIdentity ann = 
      new PersonIdentity.PersonBuilder().
      setGender(Gender.Female).
      setTitle("Dr.").
      addGivenName("Ann").
      setFamilyName("Nielsen").
      build();
    
    System.out.println("=== Ann: ===");
    System.out.println(ann.toString());

  }
}

