/** Demonstration of Fluent interfaces
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
import java.util.*;

public class StreamGrade {
  public static void main(String[] args) {
    System.out.println("Simple fluent API usage in Java 8");
    // Define some students with grades 
    List<StudentExam> studentList =
      Arrays.asList( new StudentExam[] {
          new StudentExam("17", 4),
          new StudentExam("18", 7),
          new StudentExam("19", 7),
          new StudentExam("21", 0),
          new StudentExam("21", 2),
          new StudentExam("22", 12)});
    System.out.println("Average grade is: " +
                        studentList
                        .stream()
                        .mapToInt(exam -> exam.grade)
                        .average()
                       .orElse(0.0));
    System.out.println("Average of passed grade (>=2) is: " +
                       studentList
                       .stream()
                       .filter(exam -> exam.grade >= 2)
                       .mapToInt(exam -> exam.grade)
                       .average()
                       .orElse(0.0));
    
  }
}

class StudentExam {
  public int grade;
  public String studentId;
  public StudentExam(String id, int g) {
    grade = g; studentId = id;
  }
}
