package paystation.domain;

import org.junit.*;
import static org.junit.Assert.*;

import java.util.*;

/** Test the output calculated from the TimeDisplayStrategy.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestTimeDisplay {
  private DisplayStrategy ds;

  @Before public void setUp() {
    ds = new TimeDisplayStrategy();
  }

  /* This test case is a balance as its complexity is actually equal
     to the production code. Another approach would have been to
     introduce a test stub for the system clock which could then be
     set by the JUnit testing code. However, again the cost of this
     operation is higher than the gain in reliability, therefore this
     path was taken. Note also that there is a very small chance that
     this test case actually fails as the time is sampled twice and
     the time for calculating the result below may be a small fraction
     off that of the display strategy. If they sample on different
     sides of the minute boundary it may fail. */
  @Test public void shouldDisplayTimeCorrectly() {
    int minutes = 10; /* 10 minutes bought */
    Calendar now = GregorianCalendar.getInstance();
    now.add(Calendar.MINUTE, 10);
    int result =
      now.get(Calendar.HOUR_OF_DAY) * 100 
      + 
      now.get(Calendar.MINUTE);
    
    assertEquals("10 min from now should be"+result, 
                 result, ds.calculateOutput(10));
  }
} 
