/** A simple demonstration of the Observer pattern.
    A cell in a spread sheet is monitored by two observers.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
import java.util.*;

public class DemoObserver {
  public static void main(String[] args) {
    SpreadsheetCell a1 = new SpreadsheetCell();
    Observer 
      observer1 = new PieChartWindow(a1),
      observer2 = new BarChartWindow(a1);
    a1.addObserver(observer1); 
    a1.addObserver(observer2);

    a1.changeValue(32);
    a1.changeValue(42);
    
    a1.removeObserver(observer1);
    a1.changeValue(12);
  }
}
class PieChartWindow implements Observer {
  SpreadsheetCell myCell;
  public PieChartWindow(SpreadsheetCell c){
    myCell = c;
  }
  public void update() {
    System.out.println( "Pie chart notified: value: "+
                        myCell.getValue() );
  }
}
class BarChartWindow implements Observer {
  SpreadsheetCell myCell;
  public BarChartWindow(SpreadsheetCell c){
    myCell = c;
  }
  public void update() {
    System.out.println( "Value "+ myCell.getValue()+
                        " in Bar chart" );
  }
}