/** A concrete example of a subject in the Observer pattern.
    Here it is the 'bare bones' of a spreadsheet cell whose
    integer value can be monitored.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
import java.util.*;

public class SpreadsheetCell implements Subject {
  private int value = 0;
  
  /** change the value of the cell.
      @param value the new value in the cell.
  */
  public void changeValue(int value) { 
    this.value = value; 
    notifyObservers();
  }
  
  /** get the value of the cell.
      @return the value of this cell.
  */
  public int getValue() {
    return value;
  }
  
  private List<Observer> observerList = new ArrayList<Observer>();
  public void addObserver(Observer newObserver) { 
    observerList.add(newObserver);
  }
  public void removeObserver(Observer observer) {
    observerList.remove(observer);
  }
  public void notifyObservers() {
    for( Observer o: observerList ) {
      o.update();
    }
  }
}