/** Subject role in the Observer pattern

   Responsibilities:
			
   1) To maintain a set of observers
   2) To invoke all observers' update method whenever
      this object's state changes

 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

public interface Subject {
  /** add an observer to the set of observers receiving notifications
   * from this subject.
   * @param newObserver the observer to add to this subject's set */
  public void addObserver(Observer newObserver);
  /**  Remove the observer from the set of observers receiving
   * notifications from this subject.
   * @param observer the observer to remove from the set.*/
  public void removeObserver(Observer observer);
  /** notify all observers in case this subject has changed state. */
  public void notifyObservers();
}