import org.junit.jupiter.api.*;
import static org.junit.jupiter.api.Assertions.*;

import static org.hamcrest.MatcherAssert.assertThat; 
import static org.hamcrest.Matchers.*;

import java.util.*;

/** Demonstrating the Hamcrest Matcher library

   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestHamcrest {
  
  @Test
  public void shouldDemonstrateHamcrest() {
    int value = 42;
    assertThat(value, is(42));
    assertThat(value, is(not(41)));

    assertThat(null, is(nullValue()));
    
    String s = "This is 2nd edition of FRS";
    assertThat(s, is(notNullValue()));
    assertThat(s, containsString("2nd"));
    assertThat(s, not(containsString("1st")));

    List<String> l = new ArrayList<String>();
    l.add("Bimse");
    l.add("Bumse");
    assertThat(l, hasItems(new String[] {"Bimse","Bumse"}));

  }
}
