/** State pattern implementation of a subway turnstile.  

   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TurnstileImpl implements Turnstile {
  State 
    lockedState = new LockedState(this),
    unlockedState = new UnlockedState(this),
    state = lockedState;
  public void coin() { state.coin(); }
  public void pass() { state.pass(); }
  
  public static void main(String[] args) {
    System.out.println( "Demo of turnstile state pattern" );
    Turnstile turnstile = new TurnstileImpl();
    turnstile.coin();
    turnstile.pass();
    turnstile.pass();
    turnstile.coin();
    turnstile.coin();
  }
}

abstract class State implements Turnstile {
  protected TurnstileImpl turnstile;
  public State(TurnstileImpl ts) { turnstile = ts; }
}

class LockedState extends State {
  public LockedState(TurnstileImpl ts) { super(ts); }
  public void coin() { 
    System.out.println( "Locked state: Coin accepted");
    turnstile.state = turnstile.unlockedState;
  }
  public void pass() { 
    System.out.println( "Locked state: Passenger pass: SOUND ALARM");
  } 
}
class UnlockedState extends State {
  public UnlockedState(TurnstileImpl ts) { super(ts); }
  public void coin() { 
    System.out.println( "Unlocked state: Coin entered: RETURN IT");
  }
  public void pass() { 
    System.out.println( "Unlocked state: Passenger pass");
    turnstile.state = turnstile.lockedState;
  }
}


