/** Implementation of the pay station with a progressive
 *  rate policy.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

public class PayStationProgressiveRate extends PayStationImpl {
  protected int calculateTime(int paidSoFar) {
    int time = 0;
    if ( paidSoFar >= 150+200 ) { // from 2nd hour onwards
      paidSoFar -= 350;
      time = 120 /*min*/ + paidSoFar / 5;
    } else if ( paidSoFar >= 150 ) { // from 1st to 2nd hour
      paidSoFar -= 150;
      time = 60 /*min*/ + paidSoFar * 3 / 10;
    } else { // up to 1st hour
      time = paidSoFar * 2 / 5;
    }
    return time;
  } 
}

