import java.util.*;

/** Implementation of the Safe.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class SafeImpl implements Safe {
  private char[] displayContents;
  private int index;
  private boolean locked, enterCodeState;
  private Map<Button,Character> map;

  public SafeImpl() {
    displayContents = new char[6];
    reset();
    locked = true; enterCodeState = false;

    map = new HashMap<Button,Character>();
    map.put(Button.D1, '1'); map.put(Button.D2, '2');    
    map.put(Button.D3, '3'); map.put(Button.D4, '4');    
    map.put(Button.D5, '5'); map.put(Button.D6, '6');    
    map.put(Button.D7, '7'); map.put(Button.D8, '8');    
    map.put(Button.D9, '9'); map.put(Button.D0, '0');
  }

  public void enter(Button button) {
    // Handle state changing buttons
    if ( button == Button.KEY ) {          // KEY
      reset();
      enterCodeState = true;
    } else if ( button == Button.LOCK ) {  // LOCK
      reset();
      enterCodeState = false;
      locked = true;
    } else {                               // DIGIT 
      Character c = map.get(button);
      if ( enterCodeState ) {
        addCharacterToDisplay(c);
      } else {
        flagError();
      }
    }
  }
  
  private void addCharacterToDisplay(char c) {
    displayContents[index] = c;
    index = (index+1) % 6;
    
    if ( readDisplay().equals("123456") ) {
      locked = false;
      setDisplayContents("OPEN  ");
    } else if ( index == 0 ) { // 6 digits entered
      setDisplayContents("CLOSED");
    }
  }

  private void flagError() {
    setDisplayContents("ERROR ");
  }

  /** resets the machine to the
   * initial state.
   */
  private void reset() {
    setDisplayContents("      ");
    index = 0;
  }
  
  public boolean isLocked() {
    return locked;
  } 
  
  public String readDisplay() {
    return String.valueOf(displayContents);
  }
  
  /** PRECONDITION: string must be exactly 6 charaters long */
  private void setDisplayContents(String sixCharString) {
    for (int i = 0; i < 6; i++) 
      displayContents[i] = sixCharString.charAt(i);
  }



}

