import org.junit.*;
import static org.junit.Assert.*;

/** Test cases for Safe.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestSafe {
  private Safe safe;

  @Before
  public void setup() {
    safe = new SafeImpl();
  }

  @Test
  public void shouldInitiallyBeLockedAndCleanDisplay() {
    assertEquals("Display must be empty",
                 "      ", safe.readDisplay() );
    assertTrue("Safe must be locked", safe.isLocked());
  }

  @Test
  public void shouldDisplay123CodeAsEntered() {
    safe.enter(Button.KEY);
    safe.enter(Button.D1);
    safe.enter(Button.D2);
    safe.enter(Button.D3);
    assertEquals("Display must be 123",
                 "123   ", safe.readDisplay() );
    assertTrue("Safe must be locked", safe.isLocked());
  }

  @Test
  public void shouldUnlockSafeOnCorrectCode() {
    safe.enter(Button.KEY);
    safe.enter(Button.D1);
    safe.enter(Button.D2);
    safe.enter(Button.D3);    
    safe.enter(Button.D4);
    safe.enter(Button.D5);
    safe.enter(Button.D6);
    assertEquals("Display must be 123456",
                 "123456", safe.readDisplay() );
    assertTrue("Safe must be unlocked", !safe.isLocked());
  }
}
