import java.util.*;

/** Implementation of the Safe.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class SafeImpl implements Safe {
  private char[] displayContents;
  private int index;
  private Map<Button,Character> map;

  public SafeImpl() {
    displayContents = new char[6];
    for (int i = 0; i < 6; i++) displayContents[i] = ' ';
    index = 0;
    map = new HashMap<Button,Character>();
    map.put(Button.D1, '1');    
    map.put(Button.D2, '2');    
    map.put(Button.D3, '3');    
    map.put(Button.D7, '7');
    map.put(Button.D9, '9');
  }

  public void enter(Button button) {
    Character c = map.get(button);
    if ( c != null ) {
      displayContents[index] = c.charValue();
      index = (index+1) % 6;
    }
  }
 
  public boolean isLocked() {
    return true;
  } 
  
  public String readDisplay() {
    return String.valueOf(displayContents);
  }
  
}

