/** The specification of a simple safe.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public interface Safe {
  /** Enter a button press on the safe. */
  public void enter(Button button);

  /** Read the output of the display on the safe.
   * POSTCONDITON: It is always a non-null string of
   * exactly 6 characters that can be printed on
   * a 7-segment display.
   * @return: the output on the display
   */
  public String readDisplay();

  /** Get the state of the safe: is it locked or not.
   * @return true iff the safe is locked.
   */
  public boolean isLocked();
}

