import java.util.*;

/** Principles of Flexible Design. Common code in Abstract class exercise.
 
   This source code is from the book 
     "Flexible, Reliable Software, 2nd Edition:
       Using Patterns and Agile Development"
     First Edition published by CRC Press, 2010.
     Second Edition, available for download
       by permission.

   Author: 
     Henrik Bærbak Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class CommonCodeAbstractClass {
  public static void main(String[] args) {
    System.out.println( "* Common functionality in a abstract class design *" );
    IntegerList c;

    System.out.println( "* First Implementation *" );
    c = new FirstImplementation();
    System.out.println( "isEmpty  = "+c.isEmpty() );
    c.add(7);
    System.out.println( "isEmpty  = "+c.isEmpty() );
    c.add(9); c.add(13);
    System.out.println( "Contents = "+c.contentsAsString() );

    System.out.println( "* Second Implementation *" );
    c = new SecondImplementation();
    System.out.println( "isEmpty  = "+c.isEmpty() );
    c.add(7);
    System.out.println( "isEmpty  = "+c.isEmpty() );
    c.add(9); c.add(13);
    System.out.println( "Contents = "+c.contentsAsString() );
  }
}

abstract class IntegerList { 
  public abstract boolean add(int e);
  public abstract int get(int position);
  public abstract int size();
  // following methods are data structure independent
  public boolean isEmpty() { return size() == 0; }
  public String contentsAsString() {
    String result = "[";
    for ( int i = 0; i < size()-1; i++ ) {
      result += get(i)+", ";
    }
    return result + get(size()-1)+"]";
  }
}

class FirstImplementation extends IntegerList {
  private int contents[]; int index;
  private CommonCollectionResponsibilities common;
  public FirstImplementation() { 
    contents = new int[3]; index = 0; 
    common = new CommonImplementation(this);
  }
  public int size() { return index; }
  public boolean add(int e) { contents[index++] = e; return true; }
  public int get(int position) { return contents[position]; }
}

class SecondImplementation extends IntegerList {
  private int one,two,three; int index;
  private CommonCollectionResponsibilities common;
  public SecondImplementation() { 
    index = 0; 
    common = new CommonImplementation(this);
  }
  public int size() { return index; }
  public boolean add(int e) { 
    switch ( index ) {
    case 0: one = e; break;
    case 1: two = e; break;
    case 2: three = e; break;
    }
    index++;
    return true; 
  }
  public int get(int position) { 
    switch ( position ) {
    case 0: return one;
    case 1: return two;
    case 2: return three;
    }
    return -1; 
  }    
}  
